function varargout = Interficie_grafica_vehicles(varargin)
% INTERFICIE_GRAFICA_VEHICLES MATLAB code for Interficie_grafica_vehicles.fig
%      INTERFICIE_GRAFICA_VEHICLES, by itself, creates a new INTERFICIE_GRAFICA_VEHICLES or raises the existing
%      singleton*.
%
%      H = INTERFICIE_GRAFICA_VEHICLES returns the handle to a new INTERFICIE_GRAFICA_VEHICLES or the handle to
%      the existing singleton*.
%
%      INTERFICIE_GRAFICA_VEHICLES('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in INTERFICIE_GRAFICA_VEHICLES.M with the given input arguments.
%
%      INTERFICIE_GRAFICA_VEHICLES('Property','Value',...) creates a new INTERFICIE_GRAFICA_VEHICLES or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Interficie_grafica_vehicles_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Interficie_grafica_vehicles_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Interficie_grafica_vehicles

% Last Modified by GUIDE v2.5 30-Jul-2019 23:14:37

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Interficie_grafica_vehicles_OpeningFcn, ...
                   'gui_OutputFcn',  @Interficie_grafica_vehicles_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Interficie_grafica_vehicles is made visible.
function Interficie_grafica_vehicles_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Interficie_grafica_vehicles (see VARARGIN)

% Choose default command line output for Interficie_grafica_vehicles
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Interficie_grafica_vehicles wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Interficie_grafica_vehicles_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function var_parell_Callback(hObject, eventdata, handles)
% hObject    handle to var_parell (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of var_parell as text
%        str2double(get(hObject,'String')) returns contents of var_parell as a double


% --- Executes during object creation, after setting all properties.
function var_parell_CreateFcn(hObject, eventdata, handles)
% hObject    handle to var_parell (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function var_massa_Callback(hObject, eventdata, handles)
% hObject    handle to var_massa (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of var_massa as text
%        str2double(get(hObject,'String')) returns contents of var_massa as a double


% --- Executes during object creation, after setting all properties.
function var_massa_CreateFcn(hObject, eventdata, handles)
% hObject    handle to var_massa (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function var_dav_Callback(hObject, eventdata, handles)
% hObject    handle to var_dav (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of var_dav as text
%        str2double(get(hObject,'String')) returns contents of var_dav as a double


% --- Executes during object creation, after setting all properties.
function var_dav_CreateFcn(hObject, eventdata, handles)
% hObject    handle to var_dav (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function var_post_Callback(hObject, eventdata, handles)
% hObject    handle to var_post (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of var_post as text
%        str2double(get(hObject,'String')) returns contents of var_post as a double


% --- Executes during object creation, after setting all properties.
function var_post_CreateFcn(hObject, eventdata, handles)
% hObject    handle to var_post (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function var_radi_Callback(hObject, eventdata, handles)
% hObject    handle to var_radi (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of var_radi as text
%        str2double(get(hObject,'String')) returns contents of var_radi as a double


% --- Executes during object creation, after setting all properties.
function var_radi_CreateFcn(hObject, eventdata, handles)
% hObject    handle to var_radi (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on slider movement.
function sliderkf_Callback(hObject, eventdata, handles)
% hObject    handle to sliderkf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider


% --- Executes during object creation, after setting all properties.
function sliderkf_CreateFcn(hObject, eventdata, handles)
% hObject    handle to sliderkf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function sliderkr_Callback(hObject, eventdata, handles)
% hObject    handle to sliderkr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider


% --- Executes during object creation, after setting all properties.
function sliderkr_CreateFcn(hObject, eventdata, handles)
% hObject    handle to sliderkr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function slidercf_Callback(hObject, eventdata, handles)
% hObject    handle to slidercf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider


% --- Executes during object creation, after setting all properties.
function slidercf_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slidercf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function slidercr_Callback(hObject, eventdata, handles)
% hObject    handle to slidercr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider


% --- Executes during object creation, after setting all properties.
function slidercr_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slidercr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes during object deletion, before destroying properties.
function uitable2_DeleteFcn(hObject, eventdata, handles)
% hObject    handle to uitable2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes during object creation, after setting all properties.
function uitable2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to uitable2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called



function acc0_Callback(hObject, eventdata, handles)
% hObject    handle to acc0 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc0 as text
%        str2double(get(hObject,'String')) returns contents of acc0 as a double


% --- Executes during object creation, after setting all properties.
function acc0_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc0 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir0_Callback(hObject, eventdata, handles)
% hObject    handle to dir0 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir0 as text
%        str2double(get(hObject,'String')) returns contents of dir0 as a double


% --- Executes during object creation, after setting all properties.
function dir0_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir0 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc1_Callback(hObject, eventdata, handles)
% hObject    handle to acc1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc1 as text
%        str2double(get(hObject,'String')) returns contents of acc1 as a double


% --- Executes during object creation, after setting all properties.
function acc1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir1_Callback(hObject, eventdata, handles)
% hObject    handle to dir1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir1 as text
%        str2double(get(hObject,'String')) returns contents of dir1 as a double


% --- Executes during object creation, after setting all properties.
function dir1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc2_Callback(hObject, eventdata, handles)
% hObject    handle to acc2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc2 as text
%        str2double(get(hObject,'String')) returns contents of acc2 as a double


% --- Executes during object creation, after setting all properties.
function acc2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir2_Callback(hObject, eventdata, handles)
% hObject    handle to dir2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir2 as text
%        str2double(get(hObject,'String')) returns contents of dir2 as a double


% --- Executes during object creation, after setting all properties.
function dir2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc3_Callback(hObject, eventdata, handles)
% hObject    handle to acc3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc3 as text
%        str2double(get(hObject,'String')) returns contents of acc3 as a double


% --- Executes during object creation, after setting all properties.
function acc3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir3_Callback(hObject, eventdata, handles)
% hObject    handle to dir3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir3 as text
%        str2double(get(hObject,'String')) returns contents of dir3 as a double


% --- Executes during object creation, after setting all properties.
function dir3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc4_Callback(hObject, eventdata, handles)
% hObject    handle to acc4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc4 as text
%        str2double(get(hObject,'String')) returns contents of acc4 as a double


% --- Executes during object creation, after setting all properties.
function acc4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir4_Callback(hObject, eventdata, handles)
% hObject    handle to dir4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir4 as text
%        str2double(get(hObject,'String')) returns contents of dir4 as a double


% --- Executes during object creation, after setting all properties.
function dir4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc5_Callback(hObject, eventdata, handles)
% hObject    handle to acc5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc5 as text
%        str2double(get(hObject,'String')) returns contents of acc5 as a double


% --- Executes during object creation, after setting all properties.
function acc5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir5_Callback(hObject, eventdata, handles)
% hObject    handle to dir5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir5 as text
%        str2double(get(hObject,'String')) returns contents of dir5 as a double


% --- Executes during object creation, after setting all properties.
function dir5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc6_Callback(hObject, eventdata, handles)
% hObject    handle to acc6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc6 as text
%        str2double(get(hObject,'String')) returns contents of acc6 as a double


% --- Executes during object creation, after setting all properties.
function acc6_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir6_Callback(hObject, eventdata, handles)
% hObject    handle to dir6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir6 as text
%        str2double(get(hObject,'String')) returns contents of dir6 as a double


% --- Executes during object creation, after setting all properties.
function dir6_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc7_Callback(hObject, eventdata, handles)
% hObject    handle to acc7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc7 as text
%        str2double(get(hObject,'String')) returns contents of acc7 as a double


% --- Executes during object creation, after setting all properties.
function acc7_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir7_Callback(hObject, eventdata, handles)
% hObject    handle to dir7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir7 as text
%        str2double(get(hObject,'String')) returns contents of dir7 as a double


% --- Executes during object creation, after setting all properties.
function dir7_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc8_Callback(hObject, eventdata, handles)
% hObject    handle to acc8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc8 as text
%        str2double(get(hObject,'String')) returns contents of acc8 as a double


% --- Executes during object creation, after setting all properties.
function acc8_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir8_Callback(hObject, eventdata, handles)
% hObject    handle to dir8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir8 as text
%        str2double(get(hObject,'String')) returns contents of dir8 as a double


% --- Executes during object creation, after setting all properties.
function dir8_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc9_Callback(hObject, eventdata, handles)
% hObject    handle to acc9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc9 as text
%        str2double(get(hObject,'String')) returns contents of acc9 as a double


% --- Executes during object creation, after setting all properties.
function acc9_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir9_Callback(hObject, eventdata, handles)
% hObject    handle to dir9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir9 as text
%        str2double(get(hObject,'String')) returns contents of dir9 as a double


% --- Executes during object creation, after setting all properties.
function dir9_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function acc10_Callback(hObject, eventdata, handles)
% hObject    handle to acc10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of acc10 as text
%        str2double(get(hObject,'String')) returns contents of acc10 as a double


% --- Executes during object creation, after setting all properties.
function acc10_CreateFcn(hObject, eventdata, handles)
% hObject    handle to acc10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dir10_Callback(hObject, eventdata, handles)
% hObject    handle to dir10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dir10 as text
%        str2double(get(hObject,'String')) returns contents of dir10 as a double


% --- Executes during object creation, after setting all properties.
function dir10_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dir10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- If Enable == 'on', executes on mouse press in 5 pixel border.
% --- Otherwise, executes on mouse press in 5 pixel border or over text2.
function text2_ButtonDownFcn(hObject, eventdata, handles)
% hObject    handle to text2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)



function edit28_Callback(hObject, eventdata, handles)
% hObject    handle to edit28 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit28 as text
%        str2double(get(hObject,'String')) returns contents of edit28 as a double


% --- Executes during object creation, after setting all properties.
function edit28_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit28 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit29_Callback(hObject, eventdata, handles)
% hObject    handle to edit29 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit29 as text
%        str2double(get(hObject,'String')) returns contents of edit29 as a double


% --- Executes during object creation, after setting all properties.
function edit29_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit29 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit30_Callback(hObject, eventdata, handles)
% hObject    handle to edit30 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit30 as text
%        str2double(get(hObject,'String')) returns contents of edit30 as a double


% --- Executes during object creation, after setting all properties.
function edit30_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit30 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit31_Callback(hObject, eventdata, handles)
% hObject    handle to edit31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit31 as text
%        str2double(get(hObject,'String')) returns contents of edit31 as a double


% --- Executes during object creation, after setting all properties.
function edit31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on mouse press over axes background.
function pantalla_ButtonDownFcn(hObject, eventdata, handles)
% hObject    handle to pantalla (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in imatge.
function imatge_Callback(hObject, eventdata, handles)
% hObject    handle to imatge (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in botoexecutar.
function botoexecutar_Callback(hObject, eventdata, handles)
% hObject    handle to botoexecutar (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
massa = str2double( get(handles.massa, 'string'));
cdgdav = str2double( get(handles.cdgdav, 'string'));
cdgpost = str2double( get(handles.cdgpost, 'string'));
radi = str2double( get(handles.radi, 'string'));
%traccio = str2double( get(handles.traccio, 'string'));
parell_dav = str2double( get(handles.parell_dav, 'string'));
parell_post = str2double( get(handles.parell_post, 'string'));
kf = str2double( get(handles.kf, 'string'));
kr = str2double( get(handles.kr, 'string'));
cf = str2double( get(handles.cf, 'string'));
cr = str2double( get(handles.cr, 'string'));
acc0 = str2double( get(handles.acc0, 'string'));
acc1 = str2double( get(handles.acc1, 'string'));
acc2 = str2double( get(handles.acc2, 'string'));
acc3 = str2double( get(handles.acc3, 'string'));
acc4 = str2double( get(handles.acc4, 'string'));
acc5 = str2double( get(handles.acc5, 'string'));
acc6 = str2double( get(handles.acc6, 'string'));
acc7 = str2double( get(handles.acc7, 'string'));
acc8 = str2double( get(handles.acc8, 'string'));
acc9 = str2double( get(handles.acc9, 'string'));
acc10 = str2double( get(handles.acc10, 'string'));
dir0 = str2double( get(handles.dir0, 'string'));
dir1 = str2double( get(handles.dir1, 'string'));
dir2 = str2double( get(handles.dir2, 'string'));
dir3 = str2double( get(handles.dir3, 'string'));
dir4 = str2double( get(handles.dir4, 'string'));
dir5 = str2double( get(handles.dir5, 'string'));
dir6 = str2double( get(handles.dir6, 'string'));
dir7 = str2double( get(handles.dir7, 'string'));
dir8 = str2double( get(handles.dir8, 'string'));
dir9 = str2double( get(handles.dir9, 'string'));
dir10 = str2double( get(handles.dir10, 'string'));
velinicial = str2double( get(handles.velinicial, 'string'));

resultat = str2double( get(handles.resultat, 'string'));
resultat = 0;

fileID = fopen('exp.txt','w');
fprintf(fileID,'%d\r\n',massa,cdgdav,cdgpost,radi,parell_dav,parell_post,kf,kr,cf,cr,acc0,acc1,acc2,acc3,acc4,acc5,acc6,acc7,acc8,acc9,acc10,dir0,dir1,dir2,dir3,dir4,dir5,dir6,dir7,dir8,dir9,dir10,velinicial);
fclose(fileID);

set ( handles.resultat, 'string', num2str(resultat));

if acc0<=1 && acc0>-1 && dir0<=1 && dir0>-1 && acc1<=1 && acc1>-1 && dir1<=1 && dir1>-1 &&acc2<=1 && acc2>-1 && dir2<=1 && dir2>-1 && acc3<=1 && acc3>-1 && dir3<=1 && dir3>-1 && acc4<=1 && acc4>-1 && dir4<=1 && dir4>-1 && acc5<=1 && acc5>-1 && dir5<=1 && dir5>-1 && acc6<=1 && acc6>-1 && dir6<=1 && dir6>-1 && acc7<=1 && acc7>-1 && dir7<=1 && dir7>-1 && acc8<=1 && acc8>-1 && dir8<=1 && dir8>-1 && acc9<=1 && acc9>-1 && dir9<=1 && dir9>-1 && acc10<=1 && acc10>-1 && dir10<=1 && dir10>-1
im=imread('ok.jpg');

else
im=imread('ko.jpg');

end
imshow(im);


function kf_Callback(hObject, eventdata, handles)
% hObject    handle to kf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of kf as text
%        str2double(get(hObject,'String')) returns contents of kf as a double


% --- Executes during object creation, after setting all properties.
function kf_CreateFcn(hObject, eventdata, handles)
% hObject    handle to kf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function kr_Callback(hObject, eventdata, handles)
% hObject    handle to kr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of kr as text
%        str2double(get(hObject,'String')) returns contents of kr as a double


% --- Executes during object creation, after setting all properties.
function kr_CreateFcn(hObject, eventdata, handles)
% hObject    handle to kr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function cf_Callback(hObject, eventdata, handles)
% hObject    handle to cf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of cf as text
%        str2double(get(hObject,'String')) returns contents of cf as a double


% --- Executes during object creation, after setting all properties.
function cf_CreateFcn(hObject, eventdata, handles)
% hObject    handle to cf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function cr_Callback(hObject, eventdata, handles)
% hObject    handle to cr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of cr as text
%        str2double(get(hObject,'String')) returns contents of cr as a double


% --- Executes during object creation, after setting all properties.
function cr_CreateFcn(hObject, eventdata, handles)
% hObject    handle to cr (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in traccio.
function traccio_Callback(hObject, eventdata, handles)
% hObject    handle to traccio (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = cellstr(get(hObject,'String')) returns traccio contents as cell array
%        contents{get(hObject,'Value')} returns selected item from traccio


% --- Executes during object creation, after setting all properties.
function traccio_CreateFcn(hObject, eventdata, handles)
% hObject    handle to traccio (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function parell_Callback(hObject, eventdata, handles)
% hObject    handle to parell (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of parell as text
%        str2double(get(hObject,'String')) returns contents of parell as a double


% --- Executes during object creation, after setting all properties.
function parell_CreateFcn(hObject, eventdata, handles)
% hObject    handle to parell (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function massa_Callback(hObject, eventdata, handles)
% hObject    handle to massa (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of massa as text
%        str2double(get(hObject,'String')) returns contents of massa as a double


% --- Executes during object creation, after setting all properties.
function massa_CreateFcn(hObject, eventdata, handles)
% hObject    handle to massa (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function cdgdav_Callback(hObject, eventdata, handles)
% hObject    handle to cdgdav (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of cdgdav as text
%        str2double(get(hObject,'String')) returns contents of cdgdav as a double


% --- Executes during object creation, after setting all properties.
function cdgdav_CreateFcn(hObject, eventdata, handles)
% hObject    handle to cdgdav (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function cdgpost_Callback(hObject, eventdata, handles)
% hObject    handle to cdgpost (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of cdgpost as text
%        str2double(get(hObject,'String')) returns contents of cdgpost as a double


% --- Executes during object creation, after setting all properties.
function cdgpost_CreateFcn(hObject, eventdata, handles)
% hObject    handle to cdgpost (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function radi_Callback(hObject, eventdata, handles)
% hObject    handle to radi (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of radi as text
%        str2double(get(hObject,'String')) returns contents of radi as a double


% --- Executes during object creation, after setting all properties.
function radi_CreateFcn(hObject, eventdata, handles)
% hObject    handle to radi (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function parell_dav_Callback(hObject, eventdata, handles)
% hObject    handle to parell_dav (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of parell_dav as text
%        str2double(get(hObject,'String')) returns contents of parell_dav as a double


% --- Executes during object creation, after setting all properties.
function parell_dav_CreateFcn(hObject, eventdata, handles)
% hObject    handle to parell_dav (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function parell_post_Callback(hObject, eventdata, handles)
% hObject    handle to parell_post (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of parell_post as text
%        str2double(get(hObject,'String')) returns contents of parell_post as a double


% --- Executes during object creation, after setting all properties.
function parell_post_CreateFcn(hObject, eventdata, handles)
% hObject    handle to parell_post (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function velinicial_Callback(hObject, eventdata, handles)
% hObject    handle to velinicial (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of velinicial as text
%        str2double(get(hObject,'String')) returns contents of velinicial as a double


% --- Executes during object creation, after setting all properties.
function velinicial_CreateFcn(hObject, eventdata, handles)
% hObject    handle to velinicial (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
